==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/core/camel-base-engine/src/main/java/org/apache/camel/impl/engine/DefaultInterceptEndpointFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl.engine;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.Processor;
import org.apache.camel.spi.InterceptEndpointFactory;
import org.apache.camel.support.DefaultInterceptSendToEndpoint;

/**
 * Default {@link InterceptEndpointFactory}.
 */
public class DefaultInterceptEndpointFactory implements InterceptEndpointFactory {

    @Override
    public Endpoint createInterceptSendToEndpoint(
            CamelContext camelContext, Endpoint endpoint, boolean skip, Processor before, Processor after) {
        DefaultInterceptSendToEndpoint answer = new DefaultInterceptSendToEndpoint(endpoint, skip);
        answer.setBefore(before);
        answer.setAfter(after);
        return answer;
    }
}

==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/core/camel-base-engine/src/main/java/org/apache/camel/impl/engine/DefaultInterceptEndpointFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl.engine;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.Predicate;
import org.apache.camel.Processor;
import org.apache.camel.spi.InterceptEndpointFactory;
import org.apache.camel.support.DefaultInterceptSendToEndpoint;

/**
 * Default {@link InterceptEndpointFactory}.
 */
public class DefaultInterceptEndpointFactory implements InterceptEndpointFactory {

    @Override
    public Endpoint createInterceptSendToEndpoint(
            CamelContext camelContext, Endpoint endpoint, boolean skip, Predicate onWhen, Processor before, Processor after) {
        DefaultInterceptSendToEndpoint answer = new DefaultInterceptSendToEndpoint(endpoint, skip);
        answer.setOnWhen(onWhen);
        answer.setBefore(before);
        answer.setAfter(after);
        return answer;
    }

}
